bayespy.inference.vmp.nodes.gaussian.GaussianGammaDistribution.plates_to_parent
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaDistribution.plates_to_parent